@@ -4,13 +4,9 @@ use std::ops::{Add, Sub};
 use bevy::prelude::*;
 use bevy_prototype_lyon::shapes;
 
-#[cfg(feature = "inspector")]
-use bevy_inspector_egui::Inspectable;
-
 use crate::prelude::{LayoutAnchor, LayoutHAnchor, LayoutVAnchor};
 
 #[derive(Copy, Clone, Debug, Default)]
-#[cfg_attr(feature = "inspector", derive(Inspectable))]
 pub struct LayoutSize {
     pub width: f32,
     pub height: f32,
@@ -50,7 +46,6 @@ impl LayoutConstraint {
 }
 
 #[derive(Copy, Clone, Debug, Default, Component)]
-#[cfg_attr(feature = "inspector", derive(Inspectable))]
 pub struct LayoutData {
     pub depth: usize,
     pub size: LayoutSize,
